pub enum RecvError {
Disconnected,
}Expand description
An error that occurs when trying to receive a value from a channel after all senders have been dropped and there are no more messages in the channel.
Variants
Disconnected
No further messages can be received because all senders have been dropped and there are no messages waiting in the channel.