pub enum TrySendError<T> {
Full(T),
Disconnected(T),
}Expand description
An error that occurs when trying to send a value to a channel:
- When the channel is full.
- When all receivers have been dropped.
Variants
Full(T)
The message cannot be sent because the channel is full.
Disconnected(T)
All receivers have been dropped, so the message cannot be received.
Implementations
Sourceimpl<T> TrySendError<T>
impl<T> TrySendError<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume the error and return the message that failed to send.